@@ -22,7 +22,6 @@
 # THE SOFTWARE.
 #
 # ###########################################################################*/
-from fileinput import filename
 """Access to external resources.
 
 Module imported from silx project to avoid cyclic dependancy.
@@ -30,8 +29,7 @@ Module imported from silx project to avoid cyclic dependancy.
 
 __authors__ = ["Thomas Vincent", "J. Kieffer"]
 __license__ = "MIT"
-__date__ = "23/10/2019"
-
+__date__ = "14/04/2020"
 
 import os
 import threading
@@ -39,9 +37,9 @@ import json
 import logging
 import tempfile
 import unittest
-from fabio.third_party import six
+import urllib.request, urllib.error
 import bz2
-from ..third_party import gzip
+import gzip
 
 logger = logging.getLogger(__name__)
 
@@ -146,17 +144,17 @@ class ExternalResources(object):
             if "https_proxy" in os.environ:
                 dictProxies['https'] = os.environ["https_proxy"]
             if dictProxies:
-                proxy_handler = six.moves.urllib.request.ProxyHandler(dictProxies)
-                opener = six.moves.urllib.request.build_opener(proxy_handler).open
+                proxy_handler = urllib.request.ProxyHandler(dictProxies)
+                opener = urllib.request.build_opener(proxy_handler).open
             else:
-                opener = six.moves.urllib.request.urlopen
+                opener = urllib.request.urlopen
 
             logger.debug("wget %s/%s", self.url_base, filename)
             try:
                 data = opener("%s/%s" % (self.url_base, filename),
                               data=None, timeout=self.timeout).read()
                 logger.info("Image %s successfully downloaded.", filename)
-            except six.moves.urllib.error.URLError:
+            except urllib.error.URLError:
                 raise unittest.SkipTest("network unreachable.")
 
             if not os.path.isdir(os.path.dirname(fullfilename)):
@@ -172,11 +170,11 @@ class ExternalResources(object):
 
             if not os.path.isfile(fullfilename):
                 raise RuntimeError(
-                    ("Could not automatically download test images %s!"%filename)+
-                    "If you are behind a firewall, please set both environment variable http_proxy and https_proxy."+
-                    "This works even under windows !"+
-                    "Otherwise please try to download the images manually from"+
-                    "%s/%s"% (self.url_base, filename))
+                    ("Could not automatically download test images %s!" % filename) +
+                    "If you are behind a firewall, please set both environment variable http_proxy and https_proxy." +
+                    "This works even under windows !" +
+                    "Otherwise please try to download the images manually from" +
+                    "%s/%s" % (self.url_base, filename))
 
         if filename not in self.all_data:
             self.all_data.add(filename)
@@ -269,7 +267,7 @@ class ExternalResources(object):
             self.getfile(bzip2name)
             if not os.path.isfile(fullimagename_bz2):
                 raise RuntimeError(
-                    ("Could not automatically download test images %s!"%filename) +
+                    ("Could not automatically download test images %s!" % filename) +
                     "If you are behind a firewall, please set the environment variable http_proxy and https_proxy." +
                     "Otherwise please try to download the images manually from" +
                     "%s/%s" % (self.url_base, filename))
